@@ -72,6 +72,7 @@ typedef struct RunModes_ {
  * A list of output modules that will be active for the run mode.
  */
 typedef struct RunModeOutput_ {
+    const char *name;
     TmModule *tm_module;
     OutputCtx *output_ctx;
 
@@ -491,6 +492,31 @@ static void AddOutputToFreeList(OutputModule *module, OutputCtx *output_ctx)
     TAILQ_INSERT_TAIL(&output_free_list, fl_output, entries);
 }
 
+static int GetRunModeOutputPriority(RunModeOutput *module)
+{
+    TmModule *tm = TmModuleGetByName(module->name);
+    if (tm == NULL)
+        return 0;
+
+    return tm->priority;
+}
+
+static void InsertInRunModeOutputs(RunModeOutput *runmode_output)
+{
+    RunModeOutput *r_output = NULL;
+    int output_priority = GetRunModeOutputPriority(runmode_output);
+
+    TAILQ_FOREACH(r_output, &RunModeOutputs, entries) {
+        if (GetRunModeOutputPriority(r_output) < output_priority)
+            break;
+    }
+    if (r_output) {
+        TAILQ_INSERT_BEFORE(r_output, runmode_output, entries);
+    } else {
+        TAILQ_INSERT_TAIL(&RunModeOutputs, runmode_output, entries);
+    }
+}
+
 /** \brief Turn output into thread module */
 static void SetupOutput(const char *name, OutputModule *module, OutputCtx *output_ctx)
 {
@@ -520,9 +546,10 @@ static void SetupOutput(const char *name, OutputModule *module, OutputCtx *outpu
             RunModeOutput *runmode_output = SCCalloc(1, sizeof(RunModeOutput));
             if (unlikely(runmode_output == NULL))
                 return;
+            runmode_output->name = module->name;
             runmode_output->tm_module = pkt_logger_module;
             runmode_output->output_ctx = NULL;
-            TAILQ_INSERT_TAIL(&RunModeOutputs, runmode_output, entries);
+            InsertInRunModeOutputs(runmode_output);
             SCLogDebug("__packet_logger__ added");
         }
     } else if (module->TxLogFunc) {
@@ -542,9 +569,10 @@ static void SetupOutput(const char *name, OutputModule *module, OutputCtx *outpu
             RunModeOutput *runmode_output = SCCalloc(1, sizeof(RunModeOutput));
             if (unlikely(runmode_output == NULL))
                 return;
+            runmode_output->name = module->name;
             runmode_output->tm_module = tx_logger_module;
             runmode_output->output_ctx = NULL;
-            TAILQ_INSERT_TAIL(&RunModeOutputs, runmode_output, entries);
+            InsertInRunModeOutputs(runmode_output);
             SCLogDebug("__tx_logger__ added");
         }
     } else if (module->FiledataLogFunc) {
@@ -563,9 +591,10 @@ static void SetupOutput(const char *name, OutputModule *module, OutputCtx *outpu
             RunModeOutput *runmode_output = SCCalloc(1, sizeof(RunModeOutput));
             if (unlikely(runmode_output == NULL))
                 return;
+            runmode_output->name = module->name;
             runmode_output->tm_module = filedata_logger_module;
             runmode_output->output_ctx = NULL;
-            TAILQ_INSERT_TAIL(&RunModeOutputs, runmode_output, entries);
+            InsertInRunModeOutputs(runmode_output);
             SCLogDebug("__filedata_logger__ added");
         }
     } else if (module->FileLogFunc) {
@@ -584,9 +613,10 @@ static void SetupOutput(const char *name, OutputModule *module, OutputCtx *outpu
             RunModeOutput *runmode_output = SCCalloc(1, sizeof(RunModeOutput));
             if (unlikely(runmode_output == NULL))
                 return;
+            runmode_output->name = module->name;
             runmode_output->tm_module = file_logger_module;
             runmode_output->output_ctx = NULL;
-            TAILQ_INSERT_TAIL(&RunModeOutputs, runmode_output, entries);
+            InsertInRunModeOutputs(runmode_output);
             SCLogDebug("__file_logger__ added");
         }
     } else {
